==> autoprofile_2.10.orig.tar.gz: autoprofile-2.10/src/component.c <==
/*--------------------------------------------------------------------------*
 * AUTOPROFILE                                                              *
 *                                                                          *
 * A Gaim away message and profile manager that supports dynamic text       *
 *                                                                          *
 * AutoProfile is the legal property of its developers.  Please refer to    *
 * the COPYRIGHT file distributed with this source distribution.            *
 *                                                                          *
 * This program is free software; you can redistribute it and/or modify     *
 * it under the terms of the GNU General Public License as published by     *
 * the Free Software Foundation; either version 2 of the License, or        *
 * (at your option) any later version.                                      *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA *
 *--------------------------------------------------------------------------*/

#include "component.h"

GList *get_components ()
{
  GList *ret = NULL;
  /* Add each listed component */
  ret = g_list_append (ret, &count);
  ret = g_list_append (ret, &quote);
  #ifndef _WIN32
  ret = g_list_append (ret, &executable);
  #endif
  ret = g_list_append (ret, &fortune);
  ret = g_list_append (ret, &http);
  ret = g_list_append (ret, &logstats);
  //ret = g_list_append (ret, &rss);
  ret = g_list_append (ret, &text);
  ret = g_list_append (ret, &timestamp);
     
  #ifndef _WIN32
  ret = g_list_append (ret, &uptime);
  #endif

  /* Return */
  return ret;
}

==> autoprofile_2.14.orig.tar.gz: autoprofile-2.14/src/component.c <==
/*--------------------------------------------------------------------------*
 * AUTOPROFILE                                                              *
 *                                                                          *
 * A Gaim away message and profile manager that supports dynamic text       *
 *                                                                          *
 * AutoProfile is the legal property of its developers.  Please refer to    *
 * the COPYRIGHT file distributed with this source distribution.            *
 *                                                                          *
 * This program is free software; you can redistribute it and/or modify     *
 * it under the terms of the GNU General Public License as published by     *
 * the Free Software Foundation; either version 2 of the License, or        *
 * (at your option) any later version.                                      *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA *
 *--------------------------------------------------------------------------*/

#include "component.h"

GList *get_components ()
{
  GList *ret = NULL;
  /* Add each listed component */
  ret = g_list_append (ret, &count);
  ret = g_list_append (ret, &quote);
  #ifndef _WIN32
  ret = g_list_append (ret, &executable);
  #endif
  ret = g_list_append (ret, &fortune);
  ret = g_list_append (ret, &http);
  ret = g_list_append (ret, &logstats);
  ret = g_list_append (ret, &rss);
  ret = g_list_append (ret, &text);
  ret = g_list_append (ret, &timestamp);
     
  #ifndef _WIN32
  ret = g_list_append (ret, &uptime);
  #endif

  /* Return */
  return ret;
}
